@@ -34,7 +34,7 @@ GRP3 <- function(X, by = NULL, sort = TRUE,
   }
   if (!sort && !return.groups && !is.factor(X)) {
     if (!is.null(by)) {
-      X <- cheapr::sset_df(X, j = by)
+      X <- cheapr::sset(X, j = by)
     }
     out <- cheapr::new_list(10L)
     # groups <- group2(X)
@@ -65,11 +65,11 @@ GRP3 <- function(X, by = NULL, sort = TRUE,
     out[[8L]] <- GRP_starts(out)
     if (!"locs" %in% names(out)){
       out <- c(unclass(out), list(locs = NULL))
+      class(out) <- "GRP"
     }
     if (return.locs){
       out[[10L]] <- GRP_loc(out)
     }
-    class(out) <- "GRP"
   }
   out
 }
@@ -146,7 +146,7 @@ GRP_group_sizes <- function(GRP){
   GRP[["group.sizes"]]
 }
 GRP_expanded_group_sizes <- function(GRP){
-  GRP_group_sizes(GRP)[GRP_group_id(GRP)]
+  cheapr::sset(GRP_group_sizes(GRP), GRP_group_id(GRP))
 }
 # Groups
 GRP_groups <- function(GRP){
@@ -236,7 +236,7 @@ GRP_starts <- function(GRP, use.g.names = FALSE){
       starts <- attr(o, "starts")
       if (collapse::anyv(GRP_sizes, 0L)){
         out <- integer(GRP_n_groups(GRP))
-        out[cheapr::which_val(GRP_sizes, 0L, invert = TRUE)] <- o[starts]
+        out[cheapr::which_val(GRP_sizes, 0L, invert = TRUE)] <- cheapr::sset(o, starts)
       } else {
         out <- cheapr::attrs_rm(cheapr::sset(o, starts), .set = TRUE)
       }
@@ -272,10 +272,6 @@ GRP_ends <- function(GRP, use.g.names = FALSE){
 }
 # Extract group order from GRP object safely
 GRP_order <- function(GRP){
-  ### Only use the below arguments
-  ### If GRP_order is called from radixorderv2
-  ### Otherwise leave as is
-  # starts = TRUE, group.sizes = FALSE, sort = TRUE){
   if (is.null(GRP)){
     return(NULL)
   }
@@ -301,7 +297,7 @@ GRP_order <- function(GRP){
 }
 
 # Alternative to gsplit(NULL, g)
-GRP_loc <- function(GRP, use.g.names = FALSE){
+GRP_loc <- function(GRP){
 
   locs <- GRP[["locs"]]
   if (!is.null(locs)){
@@ -310,22 +306,12 @@ GRP_loc <- function(GRP, use.g.names = FALSE){
   group_id <- GRP_group_id(GRP)
   group_sizes <- GRP_group_sizes(GRP)
   group_order <- GRP[["order"]]
-  if (!is.null(group_order)){
-    out <- cpp_group_locs(group_order, group_sizes)
-    if (use.g.names){
-      names(out) <- GRP_names(GRP)
-    }
-  } else if (length(group_id) == 0L){
-    if (use.g.names){
-      out <- add_names(list(), character(0))
-    } else {
-      out <- list()
-    }
+
+  if (is.null(group_order)){
+    cpp_group_locs2(group_id, group_sizes)
   } else {
-    out <- cpp_group_locs2(group_id, group_sizes)
-    # out <- collapse::gsplit(NULL, g = GRP, use.g.names = use.g.names)
+    cpp_group_locs(group_order, group_sizes)
   }
-  out
 }
 
 group_locs <- function(x){
@@ -338,18 +324,6 @@ group_locs <- function(x){
     cpp_group_locs(o, attr(o, "group.sizes"))
   }
 }
-# GRP starts & ends from list of group locations
-# Groups are assumed to be sorted and
-# index locations are also assumed to be sorted
-GRP_loc_starts <- function(loc){
-  cpp_pluck_list_of_integers(loc, 1L, 0L)
-}
-GRP_loc_ends <- function(loc, sizes = NULL){
-  if (is.null(sizes)){
-    sizes <- cheapr::list_lengths(loc)
-  }
-  cpp_pluck_list_of_integers(loc, sizes, 0L)
-}
 GRP_ordered <- function(GRP){
   GRP[["ordered"]]
 }
@@ -365,17 +339,23 @@ GRP_is_sorted <- function(GRP){
   isTRUE(ordered[names(ordered) == "sorted"])
 }
 GRP_group_data <- function(GRP, expand = FALSE){
-  out <- list_as_tbl(as.list(GRP_groups(GRP)))
+  out <- as_tbl(GRP_groups(GRP))
   if (expand){
-    out <- cheapr::sset_df(out, GRP_group_id(GRP))
+    out <- cheapr::sset(out, GRP_group_id(GRP))
   }
   out
 }
 
 GRP_names <- function(GRP, sep = "_", expand = FALSE, force.char = FALSE){
-  g_names <- collapse::GRPnames(GRP, force.char = force.char, sep = sep)
+
+  if (is.null(GRP)){
+    return(NULL)
+  }
+
+  groups <- GRP_group_data(GRP)
+  g_names <- df_paste_names(groups, sep = sep)
   if (expand && !is.null(g_names)){
-    g_names[GRP_group_id(GRP)]
+    cheapr::sset(g_names, GRP_group_id(GRP))
   } else {
     g_names
   }
@@ -399,7 +379,7 @@ df_to_GRP <- function(data, .cols = character(),
   dplyr_groups <- f_group_vars(data)
   cols <- drop_names(col_select_names(data, .cols = .cols))
   extra_groups <- vec_setdiff(cols, dplyr_groups)
-  data2 <- cheapr::sset_df(data, j = cols)
+  data2 <- cheapr::sset(data, j = cols)
 
   if (length(names(data2)) == 0L){
     out <- grouped_df_as_GRP(cpp_ungroup(data2),
@@ -533,20 +513,6 @@ radixorderv2 <- function(x, na.last = TRUE, decreasing = FALSE,
                         na.last = na.last, decreasing = decreasing)
 }
 
-# Helper to grab group sizes
-group_sizes <- function(x, sort = FALSE, expand = FALSE){
-  if (sort && !expand){
-    groups <- radixorderv2(x, group.sizes = TRUE, sort = TRUE)
-  } else {
-    groups <- group2(x)
-  }
-  out <- attr(groups, "group.sizes")
-  if (expand){
-    out <- out[groups]
-  }
-  out
-}
-
 ## Construct a grouped data frame from a GRP object
 
 construct_grouped_df <- function(data, g, group_vars){
@@ -558,7 +524,7 @@ construct_grouped_df <- function(data, g, group_vars){
   groups <- GRP_groups(g)
 
   if (is.null(groups)){
-    groups <- cheapr::sset_df(cpp_ungroup(data), GRP_starts(g), j = group_vars)
+    groups <- cheapr::sset(cpp_ungroup(data), GRP_starts(g), j = group_vars)
   }
   group_locs <- GRP_loc(g)
   groups[[".rows"]] <- as_list_of_ints(group_locs)
@@ -570,17 +536,6 @@ construct_grouped_df <- function(data, g, group_vars){
   out
 }
 
-GRP_names <- function(GRP, sep = "_", expand = FALSE, force.char = FALSE){
-  g_names <- collapse::GRPnames(GRP, force.char = force.char,
-                                sep = sep)
-  if (expand && !is.null(g_names)) {
-    g_names[GRP_group_id(GRP)]
-  }
-  else {
-    g_names
-  }
-}
-
 grouped_first <- function(x, na.rm = TRUE, g = NULL, TRA = NULL, use.g.names = FALSE){
   if (is.null(g)){
     first <- cheapr::sset(x, min(1L, vector_length(x)))
@@ -680,25 +635,16 @@ grouped_lead <- function(x, n = 1L, fill = NULL, g = NULL, order_by = NULL){
   grouped_lag(x, n = -n, fill = fill, g = g, order_by = order_by)
 }
 
-vec_group_split <- function(x, g){
+vec_group_split <- function(x, g, order = TRUE){
   if (is.null(g)){
     list(x)
   } else {
-    g <- GRP2(g)
+    g <- GRP2(g, return.locs = TRUE, return.order = order, sort = order)
     locs <- GRP_loc(g)
     cpp_vec_group_split(x, locs)
   }
 }
 
 gsplit2 <- function(x = NULL, g = NULL){
-  g <- GRP2(g)
-  if (is.null(g)){
-    list(x)
-  } else {
-    if (cpp_is_simple_atomic_vec(x)){
-      collapse::gsplit(x, g = g)
-    } else {
-      vec_group_split(x, g = g)
-    }
-  }
+  vec_group_split(x, g)
 }
