@@ -23,7 +23,7 @@ remove_rows_if_any_na <- function(.data, ..., .cols = NULL){
   if (length(keep) == df_nrow(.data)){
     .data
   } else {
-    cheapr::sset_df(.data, keep)
+    cheapr::sset(.data, keep)
   }
 }
 #' @rdname remove_na
@@ -39,6 +39,6 @@ remove_rows_if_all_na <- function(.data, ..., .cols = NULL){
   if (length(keep) == df_nrow(.data)){
     .data
   } else {
-    cheapr::sset_df(.data, keep)
+    cheapr::sset(.data, keep)
   }
 }
