@@ -134,7 +134,7 @@ mutate_summary <- function(.data, ...,
 
     # Add missed group vars and keep original ordering
     keep_cols <- vec_intersect(all_cols, c(all_groups, keep_cols))
-    out_data <- cheapr::sset_df(out_data, j = keep_cols)
+    out_data <- cheapr::sset(out_data, j = keep_cols)
   }
   list(
     data = out_data,
@@ -188,10 +188,9 @@ select_summary <- function(.data, ..., .by = NULL, .cols = NULL, .order = group_
 }
 
 tidy_dots_info <- function(.data, ..., .by = NULL, .cols = NULL,
-                           .order = group_by_order_default(.data),
-                           .type = "data-mask"){
+                           .order = group_by_order_default(.data)){
   check_cols(n_dots = dots_length(...), .cols = .cols)
-  if (is.null(.cols) && .type == "data-mask"){
+  if (is.null(.cols)){
     mutate_summary(.data, ..., .by = {{ .by }}, .order = .order)
   } else {
     select_summary(.data, ..., .by = {{ .by }}, .order = .order, .cols = .cols)
@@ -204,11 +203,10 @@ tidy_dots_info <- function(.data, ..., .by = NULL, .cols = NULL,
 
 tidy_eval_groups <- function(.data, ..., .by = NULL, .cols = NULL,
                              .order = group_by_order_default(.data),
-                             .type = "data-mask",
                              return_order = FALSE){
 
   info <- tidy_dots_info(.data, ..., .by = {{ .by }}, .cols = .cols,
-                         .order = .order, .type = .type)
+                         .order = .order)
   data <- info[["data"]]
   groups <- info[["all_groups"]]
   new_cols <- info[["new_cols"]]
@@ -458,7 +456,7 @@ eval_all_tidy <- function(data, quos, recycle = FALSE){
   group_unaware <- attr(quos, ".group_unaware", TRUE)
 
   if (is.null(GRP)){
-    GRP <- df_as_one_GRP(data)
+    GRP <- grouped_df_as_GRP(f_ungroup(data))
     cheapr::attrs_modify(
       quos, .GRP = GRP, .set = TRUE
     )
@@ -490,7 +488,7 @@ eval_all_tidy <- function(data, quos, recycle = FALSE){
     cheapr::attrs_modify(
       quos, .GRP = GRP, .set = TRUE
     )
-    data <- df_add_cols(
+    data <- cheapr::df_modify(
       data, list(.internal.x = GRP_group_id(GRP))
     )
   }
@@ -569,7 +567,7 @@ eval_all_tidy <- function(data, quos, recycle = FALSE){
         x
       })
 
-      split_results <- purrr::map2(results, grps, \(x, g) gsplit2(x, g = g))
+      split_results <- purrr::map2(results, grps, \(x, g) vec_group_split(x, g))
       split_results <- transpose_eval_results(split_results)
       split_results <- recycle_eval_results(split_results)
       split_results <- transpose_eval_results(split_results)
@@ -647,7 +645,6 @@ eval_summarise <- function(data, quos){
     }
   }
 
-
   groups <- regular_results[[1]]
 
   results <- cheapr::new_list(length(quos))
@@ -691,8 +688,6 @@ eval_mutate <- function(data, quos){
     }
   }
 
-
-
   results <- cheapr::new_list(length(quos))
   results[which_regular] <- regular_results
   results[which_optimised] <- optimised_results
@@ -701,125 +696,6 @@ eval_mutate <- function(data, quos){
   results
 }
 
-mutate_summary_ungrouped <- function(.data, ..., .keep = c("all", "used", "unused", "none"),
-          error_call = rlang::caller_env()){
-  .data |>
-    f_ungroup() |>
-    mutate_summary(..., .keep = rlang::arg_match(.keep)) |>
-    vec_rename(cols = "new_cols") |>
-    cheapr::sset(c("data", "cols"))
-}
-
-mutate_summary_grouped <- function (.data, ..., .keep = c("all", "used", "unused", "none"),
-          .by = NULL, error_call = rlang::caller_env()){
-  .data |>
-    mutate_summary(..., .keep = rlang::arg_match(.keep), .by = {{ .by }}) |>
-    vec_rename(cols = "new_cols") |>
-    cheapr::sset(c("data", "cols"))
-}
-
-tidy_group_info_datamask <- function(data, ..., .by = NULL,
-                                     ungroup = TRUE,
-                                     unique_groups = TRUE){
-  group_vars <- get_groups(data, {{ .by }})
-  extra_groups <- character()
-  if (ungroup){
-    out <- cpp_ungroup(data)
-  } else {
-    out <- data
-  }
-  # Data-masking for dots expressions
-  if (dots_length(...) > 0){
-    out_info <- mutate_summary(out, ..., .by = {{ .by }})
-    out <- out_info[["data"]]
-    extra_groups <- out_info[["new_cols"]]
-    GRP <- out_info[["GRP"]]
-  } else {
-    out_info <- NULL
-    GRP <- NULL
-  }
-  if (unique_groups){
-    extra_groups <- vec_setdiff(extra_groups, group_vars)
-    all_groups <- c(group_vars, extra_groups)
-  } else {
-    all_groups <- c(group_vars, vec_setdiff(extra_groups, group_vars))
-  }
-  if (is.null(out_info)){
-    changed_groups <- character()
-    address_equal <- add_names(logical(length(names(data))), names(data))
-  } else {
-    changed_groups <- vec_intersect(names(data), out_info[["changed_cols"]])
-    address_equal <- add_names(is.na(match(names(data), out_info[["changed_cols"]])), names(data))
-  }
-  list(
-    data = out,
-    dplyr_groups = group_vars,
-    extra_groups = extra_groups,
-    all_groups = all_groups,
-    changed_groups = changed_groups,
-    groups_changed = !all(address_equal[group_vars]),
-    address_equal = address_equal,
-    GRP = GRP
-  )
-}
-
-tidy_group_info_tidyselect <- function(data, ..., .by = NULL, .cols = NULL,
-                                       ungroup = TRUE, rename = TRUE,
-                                       unique_groups = TRUE){
-  group_vars <- get_groups(data, {{ .by }})
-  group_pos <- match(group_vars, names(data))
-  extra_groups <- character()
-  if (ungroup){
-    out <- cpp_ungroup(data)
-  } else {
-    out <- data
-  }
-  extra_group_pos <- tidy_select_pos(out, ..., .cols = .cols)
-  if (!rename){
-    names(extra_group_pos) <- names(data)[extra_group_pos]
-  }
-  out <- f_rename(out, .cols = extra_group_pos)
-  extra_groups <- names(extra_group_pos)
-  # Recalculate group vars in case they were renamed
-  group_vars <- names(out)[group_pos]
-  address_equal <- rep_len(TRUE, df_ncol(data))
-  address_equal[extra_group_pos] <-
-    names(data)[extra_group_pos] == names(extra_group_pos)
-  names(address_equal) <- names(data)
-  any_groups_changed <- !all(address_equal[group_vars])
-  if (unique_groups){
-    extra_groups <- vec_setdiff(extra_groups, group_vars)
-    all_groups <- c(group_vars, extra_groups)
-  } else {
-    all_groups <- c(group_vars, vec_setdiff(extra_groups, group_vars))
-  }
-  list("data" = out,
-       "dplyr_groups" = group_vars,
-       "extra_groups" = extra_groups,
-       "all_groups" = all_groups,
-       "groups_changed" = any_groups_changed,
-       "address_equal" = address_equal)
-}
-
-tidy_group_info <- function(data, ..., .by = NULL, .cols = NULL,
-                            ungroup = TRUE, rename = TRUE,
-                            dots_type = "data-mask",
-                            unique_groups = TRUE){
-  check_cols(n_dots = dots_length(...), .cols = .cols)
-  if (is.null(.cols) && dots_type == "data-mask"){
-    tidy_group_info_datamask(data, ..., .by = {{ .by }},
-                             ungroup = ungroup,
-                             unique_groups = unique_groups)
-
-  } else {
-    tidy_group_info_tidyselect(data, ..., .by = {{ .by }},
-                               .cols = .cols,
-                               ungroup = ungroup,
-                               rename = rename,
-                               unique_groups = unique_groups)
-  }
-}
-
 # tidy_overview <- function(x, ...){
 #   ovrvw <- overview(x, ...)
 #   for (i in seq_along(ovrvw)){
