@@ -1,5 +1,4 @@
 #include "fastplyr.h"
-#include "cheapr_api.h"
 #include <R.h>
 
 SEXP get_list_element(SEXP list, const char *str){
@@ -274,7 +273,7 @@ SEXP cpp_which_all(SEXP x){
   } else {
     SEXP lgl = SHIELD(new_vec(LGLSXP, n_rows)); ++NP;
     int* __restrict__ p_lgl = INTEGER(lgl);
-    safe_memset(p_lgl, 0, n_rows * sizeof(int));
+    std::fill(p_lgl, p_lgl + n_rows, 0);
 
     // Save pointers to logical cols
 
@@ -838,21 +837,6 @@ SEXP common_length(SEXP x){
   return out <= std::numeric_limits<int>::max() ? Rf_ScalarInteger(out) : Rf_ScalarReal(out);
 }
 
-// Combine two vectors
-
-SEXP binary_combine(SEXP x, SEXP y){
-
-  SEXP container = SHIELD(new_vec(VECSXP, 2));
-
-  SET_VECTOR_ELT(container, 0, x);
-  SET_VECTOR_ELT(container, 1, y);
-
-  SEXP out = SHIELD(cheapr::c(container));
-
-  YIELD(2);
-  return out;
-}
-
 SEXP compact_int_seq_len(int n){
   if (n == NA_INTEGER || n < 0){
     Rf_error("`n` must be >= 0");
