@@ -1,5 +1,4 @@
 #include "fastplyr.h"
-#include "cheapr_api.h"
 
 // Just a wrapper around rlang::eval_tidy
 // but only supplying a quosure and data mask
@@ -107,9 +106,10 @@ void set_as_vctrs_new_list_of_int(SEXP x){
   SET_STRING_ELT(rows_class, 0, Rf_mkChar("vctrs_list_of"));
   SET_STRING_ELT(rows_class, 1, Rf_mkChar("vctrs_vctr"));
   SET_STRING_ELT(rows_class, 2, Rf_mkChar("list"));
-  Rf_setAttrib(x, Rf_install("ptype"), new_vec(INTSXP, 0));
+  SEXP ptype = SHIELD(new_vec(INTSXP, 0));
+  Rf_setAttrib(x, Rf_install("ptype"), ptype);
   Rf_classgets(x, rows_class);
-  YIELD(1);
+  YIELD(2);
 }
 
 // Inspired by purrr::transpose
@@ -1005,119 +1005,6 @@ SEXP cpp_grouped_eval_mutate(SEXP data, SEXP quos){
   return results;
 }
 
-[[cpp11::register]]
-SEXP cpp_nest_split(SEXP data, SEXP drop, SEXP order){
-  int32_t NP = 0;
-
-  SEXP tbl_class = SHIELD(new_vec(STRSXP, 3)); ++NP;
-  SET_STRING_ELT(tbl_class, 0, Rf_mkChar("tbl_df"));
-  SET_STRING_ELT(tbl_class, 1, Rf_mkChar("tbl"));
-  SET_STRING_ELT(tbl_class, 2, Rf_mkChar("data.frame"));
-
-  SEXP group_data = SHIELD(cpp_group_data(data)); ++NP;
-  SEXP group_vars = SHIELD(cpp_group_vars(data)); ++NP;
-  SEXP rows = SHIELD(cpp_group_rows(data)); ++NP;
-  SEXP names = SHIELD(get_names(data)); ++NP;
-  SEXP frame;
-
-  PROTECT_INDEX frame_idx;
-  R_ProtectWithIndex(frame = R_NilValue, &frame_idx); ++NP;
-
-  SEXP temp_cols = SHIELD(cheapr::setdiff(names, group_vars, false)); ++NP;
-  SEXP temp = SHIELD(cheapr::df_select(data, temp_cols)); ++NP;
-
-  const SEXP *p_rows = VECTOR_PTR_RO(rows);
-  int n_groups = Rf_length(rows);
-  SEXP frames = SHIELD(new_vec(VECSXP, n_groups)); ++NP;
-  SHALLOW_DUPLICATE_ATTRIB(frames, rows);
-
-
-  // Slice group chunks
-
-  for (int i = 0; i < n_groups; ++i){
-    R_Reprotect(frame = cheapr::df_slice(temp, p_rows[i], false), frame_idx);
-    Rf_classgets(frame, tbl_class);
-    SET_VECTOR_ELT(frames, i, frame);
-  }
-
-  SEXP out = SHIELD(Rf_shallow_duplicate(group_data)); ++NP;
-  SEXP out_names = SHIELD(Rf_duplicate(get_names(out))); ++NP;
-  SET_STRING_ELT(out_names, Rf_length(out) - 1, Rf_mkChar("data"));
-  set_names(out, out_names);
-
-
-  // Set prototype of data
-
-  SEXP frames_class = SHIELD(new_vec(STRSXP, 3)); ++NP;
-  SET_STRING_ELT(frames_class, 0, Rf_mkChar("vctrs_list_of"));
-  SET_STRING_ELT(frames_class, 1, Rf_mkChar("vctrs_vctr"));
-  SET_STRING_ELT(frames_class, 2, Rf_mkChar("list"));
-  SEXP frame_ptype = SHIELD(cheapr::get_ptype(VECTOR_ELT(frames, 0))); ++NP;
-  set_as_tbl(frame_ptype);
-  Rf_setAttrib(frames, Rf_install("ptype"), frame_ptype);
-  Rf_classgets(frames, frames_class);
-
-  SET_VECTOR_ELT(out, Rf_length(out) - 1, frames);
-
-  // Add groups attribute
-
-  SEXP groups = SHIELD(Rf_shallow_duplicate(group_data)); ++NP;
-  Rf_setAttrib(groups, Rf_install(".drop"), drop);
-  Rf_setAttrib(groups, Rf_install("ordered"), order);
-  SEXP group_rows_seq = SHIELD(cheapr::seq_len(df_nrow(groups))); ++NP;
-  SEXP group_rows = SHIELD(Rf_coerceVector(group_rows_seq, VECSXP)); ++NP;
-  set_as_vctrs_new_list_of_int(group_rows);
-  SET_VECTOR_ELT(groups, Rf_length(groups) - 1, group_rows);
-  Rf_setAttrib(out, Rf_install("groups"), groups);
-
-  SEXP out_class = SHIELD(new_vec(STRSXP, 4)); ++NP;
-
-  SET_STRING_ELT(out_class, 0, Rf_mkChar("grouped_df"));
-  SET_STRING_ELT(out_class, 1, Rf_mkChar("tbl_df"));
-  SET_STRING_ELT(out_class, 2, Rf_mkChar("tbl"));
-  SET_STRING_ELT(out_class, 3, Rf_mkChar("data.frame"));
-
-  Rf_classgets(out, out_class);
-  YIELD(NP);
-  return out;
-}
-
-[[cpp11::register]]
-SEXP cpp_group_split(SEXP data){
-
-  SEXP rows = SHIELD(cpp_group_rows(data));
-  SEXP tbl_class = SHIELD(new_vec(STRSXP, 3));
-  SET_STRING_ELT(tbl_class, 0, Rf_mkChar("tbl_df"));
-  SET_STRING_ELT(tbl_class, 1, Rf_mkChar("tbl"));
-  SET_STRING_ELT(tbl_class, 2, Rf_mkChar("data.frame"));
-
-  const SEXP *p_rows = VECTOR_PTR_RO(rows);
-  int n_groups = Rf_length(rows);
-  SEXP frames = SHIELD(new_vec(VECSXP, n_groups));
-
-  SHIELD(data = cpp_ungroup(data));
-
-
-  SEXP frame;
-  PROTECT_INDEX frame_idx;
-  R_ProtectWithIndex(frame = R_NilValue, &frame_idx);
-
-  // Slice group chunks
-
-  for (int i = 0; i < n_groups; ++i){
-    R_Reprotect(frame = cheapr::df_slice(data, p_rows[i], false), frame_idx);
-    Rf_classgets(frame, tbl_class);
-    SET_VECTOR_ELT(frames, i, frame);
-
-    // A method that is fast and preserves structure of input data
-    // R_Reprotect(frame = cheapr::df_slice(data, p_rows[i], false), frame_idx);
-    // SET_VECTOR_ELT(frames, i, cheapr::rebuild(frame, data, false));
-  }
-
-  YIELD(5);
-  return frames;
-}
-
 // A fast method for converting a 'grouped_df' into a 'GRP'
 
 [[cpp11::register]]
@@ -1258,7 +1145,7 @@ SEXP cpp_grouped_df_as_grp(SEXP data){
     p_sorted_group_starts[0] = 1;
     max_group_size = max_group_size < group_size ? group_size : max_group_size;
 
-    safe_memcpy(&p_group_order[k], &p_rows_i[0], group_size * sizeof(int));
+    std::copy(&p_rows_i[0], &p_rows_i[group_size], &p_group_order[k]);
 
     for (int j = 0; j < group_size; ++j, ++k){
       p_group_id[p_rows_i[j] - 1] = 1;
@@ -1274,7 +1161,7 @@ SEXP cpp_grouped_df_as_grp(SEXP data){
       p_group_sizes[i] = group_size;
       max_group_size = max_group_size < group_size ? group_size : max_group_size;
 
-      safe_memcpy(&p_group_order[k], &p_rows_i[0], group_size * sizeof(int));
+      std::copy(&p_rows_i[0], &p_rows_i[group_size], &p_group_order[k]);
 
       for (int j = 0; j < group_size; ++j, ++k){
         p_group_id[p_rows_i[j] - 1] = i + 1;
